# Contributing Guidelines

Dear fellow CA enthusiast,

If you are reading this guidelines, you are probably as passionate
about the idea of self-emergence of lifeforms in cellular automata as
we are. Or maybe you are interested in multi-dimensional CA models
that could help us understand the laws of physics underlying the
quantum level. Either way, in case you are seeking to contribute to
our project, that's how you can do it.

1. Try to install Xentica framework along with Moire GUI, run some
   examples and give us feedback on any problems you met in the
   process. Feedback is twofold merit. On one hand, it is the the
   quickest way to fix the problems occured with particular system
   setups and to make the whole core framework more available to the
   mass use. At the other hand, it is the signal that the project is
   not unclaimed, which gives the core developers the inspiration to
   move on.
2. In case you succeed with the previous step, you can try to build
   your own CA models with Xentica, again giving us feedback on any
   problems you met. Maybe, you'll also miss some stuff and have some
   ideas about the new features. We are glad to listen and discuss
   anything that come to your mind during Xentica usage
   experience. Sharing of the source code for your own Xentica models
   is highly appreciated too.
3. In the process, you'll definitely read through the Xentica official
   documentation. The other way to contribute is help us to improve
   this doc. Typos, syntax or stylistic mistakes, if you know how to
   fix them, please let us know. Core developers are not native
   English, so any editorial help would be appreciated.
4. [LOCKED] Pull Requests are now locked until version 0.3. The main
   reason, because the framework is in very early development, and is
   a subject to massive and (possibly) backward-incompatible
   changes. If you are really willing to contribute some code in
   future, please contact us, and we'll update you as soon as
   framework API become at least semi-stable with Pull Requests
   opened.
5. [LOCKED] This item is hidden even from core developers =)

The easier way to give us feedback is by
[open an issue](https://github.com/a5kin/xentica/issues/new)
at GitHub. When doing so, please follow the
[Code of Conduct](https://github.com/a5kin/xentica/blob/master/CODE_OF_CONDUCT.md),
we are abiding. In general, just be benevolent and respect others. And
stay inspired with the beautiful world of multi-dimensional cellular
automata.

With Planck-level blessings,\
Xentica Core Team